package hg_lib

  1. Overview
  2. Docs

Module Async.With_argsSource

A type that is intended to be used to add additional arguments to every function. E.g. the provided default uses this type to represent flags that can be passed to any hg command, like "--cwd".

Sourcetype 'a t = 'a with_global_args
Sourceval map : 'a t -> f:('a -> 'b) -> 'b t