package hg_lib

  1. Overview
  2. Docs

Module Hg_private.Or_simple_errorSource

This is just a wrapper around Or_error.t. It exists because it is for very simple errors (e.g. "unexpected exit status") which you should tag to produce better errors containing, e.g., the final list of arguments passed to hg.

Sourcemodule Public : sig ... end
include module type of struct include Public end
Sourcetype 'a t = 'a Core.Or_error.t
Sourceval tag : 'a Core.Or_error.t -> string -> 'b -> ('b -> Base__.Sexp.t) -> 'a Core.Or_error.t
Sourceval simple_error : 'a -> 'a
Sourceval create : 'a -> 'a